const _ = require('lodash');
const Types = require('./Types');
const Entity = require('./Entity');

const Errors = {
    MISSING_ACCOUNT_NAME: 'Failed to create Auth entity agent without a account name',
    MISSING_ACCOUNT_ID: 'Failed to create Auth entity agent without a account id',
    MISSING_RUNTIME_ENVIRONMENT_NAME: 'Failed to create Auth entity agent without a agent name',
};

class Agent extends Entity {
    constructor(data) {
        const accountName = _.get(data, 'account.name');
        if (!accountName) {
            throw new Error(Errors.MISSING_ACCOUNT_NAME);
        }
        const accountId = _.get(data, 'account._id');
        if (!accountId) {
            throw new Error(Errors.MISSING_ACCOUNT_ID);
        }

        const name = _.get(data, 'name');
        if (!name) {
            throw new Error(Errors.MISSING_RUNTIME_ENVIRONMENT_NAME);
        }

        data.account = Entity.extractAccountData(data.account, undefined, true);

        super({
            type: Types.AGENT,
            ...data
        });
    }

    getActiveAccount() {
        return _.get(this, '_entity.account', {});
    }
}

module.exports = Agent;
