const _ = require('lodash');
const Types = require('./Types');
const Entity = require('./Entity');

const Errors = {
    MISSING_ACCOUNT_NAME: 'Failed to create Auth entity argoRuntime without a account name',
    MISSING_ACCOUNT_ID: 'Failed to create Auth entity argoRuntime without a account id',
    MISSING_NAME: 'Failed to create Auth entity argoRuntime without a name'
};

class ArgoRuntime extends Entity {
    constructor(data) {
        const accountName = _.get(data, 'account.name');
        if (!accountName) {
            throw new Error(Errors.MISSING_ACCOUNT_NAME);
        }
        const accountId = _.get(data, 'account._id');
        if (!accountId) {
            throw new Error(Errors.MISSING_ACCOUNT_ID);
        }

        const name = _.get(data, 'name');
        if (!name) {
            throw new Error(Errors.MISSING_NAME);
        }

        const gitProvider = _.get(data, 'account.csdp.gitProvider');
        const gitApiUrl = _.get(data, 'account.csdp.gitApiUrl');
        data.account = {
            ...Entity.extractAccountData(data.account, undefined, true),
            ...(gitProvider && { gitProvider }),
            ...(gitApiUrl && { gitApiUrl }),
        };

        data.name = name;

        super({
            type: Types.ARGO_RUNTIME,
            ...data,
        });
    }

    getActiveAccount() {
        return _.get(this, '_entity.account', {});
    }

    getName() {
        return _.get(this, '_entity.name', '');
    }
}

module.exports = ArgoRuntime;
