const _ = require('lodash');
const Entity = require('./Entity');
const Types = require('./Types');

const Errors = {
    MISSING_ACCOUNT_NAME: 'Failed to create Auth entity engine without an account name',
    MISSING_ACCOUNT_ID: 'Failed to create Auth entity engine without an account id',
    MISSING_WORKFLOW_ID: 'Failed to create Auth entity engine without a workflow id',
    MISSING_NAME: 'Failed to create Auth entity engine without a name',
};

class Engine extends Entity {
    constructor(data) {
        const accountName = _.get(data, 'account.name');
        if (!accountName) {
            throw new Error(Errors.MISSING_ACCOUNT_NAME);
        }

        const accountId = _.get(data, 'account._id');
        if (!accountId) {
            throw new Error(Errors.MISSING_ACCOUNT_ID);
        }

        const workflowId = _.get(data, 'workflowId');
        if (!workflowId) {
            throw new Error(Errors.MISSING_WORKFLOW_ID);
        }

        const name = _.get(data, 'name');
        if (!name) {
            throw new Error(Errors.MISSING_NAME);
        }

        data.account = Entity.extractAccountData(data.account, undefined, true);

        super({
            type: Types.ENGINE,
            ...data,
        });
    }

    getActiveAccount() {
        return _.get(this, '_entity.account', {});
    }

    getWorkflowId() {
        return _.get(this, '_entity.workflowId', {});
    }

    isValidAccount(id) {
        return _.isEqual(_.get(this, '_entity.account._id'), id);
    }

    _getPartialJson() {
        return this.toJson();
    }
}

module.exports = Engine;
