const _ = require('lodash');
const Entity = require('./Entity');
const Types = require('./Types');

const requiredParams = [
    '_id',
    'name',
    'account',
    'accountDefault',
    'tags'
];

class ExecutionContext extends Entity {
    constructor(data) {
        if (!requiredParams.every(param => _.has(data, param))) {
            throw new Error('Could not construct ExecutionContext entity with given data');
        }

        super({
            ...data,
            type: Types.EXECUTION_CONTEXT,
            _id: data._id.toString(),
            account: Entity.extractAccountData(data.account)
        });
    }

    getActiveAccount() {
        return this._entity.account;
    }

    isValidAccountId(id) {
        return _.isEqual(this.getActiveAccountId(), id);
    }

    get id() {
        return this._entity._id;
    }

    get name() {
        return this._entity.name;
    }

    get tags() {
        return this._entity.tags;
    }

    get accountDefault() {
        return this._entity.accountDefault;
    }

    get systemDefault() {
        return _.get(this, '_entity.systemDefault', false);
    }

    _getPartialJson() {
        return _.assign(
            super._getPartialJson(),
            {
                id: this.id,
                name: this.name,
                account: this.getActiveAccount(),
                tags: this.tags,
                accountDefault: this.accountDefault
            }
        );
    }
}


module.exports = ExecutionContext;
