const _ = require('lodash');
const Entity = require('./Entity');
const Types = require('./Types');

const Errors = {
    MISSING_ACCOUNT_NAME: 'Failed to create Auth entity runtime-environment without a account name',
    MISSING_ACCOUNT_ID: 'Failed to create Auth entity runtime-environment without a account id',
    MISSING_RUNTIME_ENVIRONMENT_NAME: 'Failed to create Auth entity runtime-environment without a runtime-environment name',
};

class RuntimeEnvironment extends Entity {
    constructor(data) {
        const accountName = _.get(data, 'account.name');
        if (!accountName) {
            throw new Error(Errors.MISSING_ACCOUNT_NAME);
        }

        const accountId = _.get(data, 'account._id');
        if (!accountId) {
            throw new Error(Errors.MISSING_ACCOUNT_ID);
        }

        const name = _.get(data, 'name');
        if (!name) {
            throw new Error(Errors.MISSING_RUNTIME_ENVIRONMENT_NAME);
        }

        data.account = Entity.extractAccountData(data.account, undefined, true);

        super({
            type: Types.RUNTIME_ENVIRONMENT,
            ...data,
        });
    }

    getActiveAccount() {
        return _.get(this, '_entity.account', {});
    }

    getName() {
        return _.get(this, '_entity.name', '');
    }

    isValidAccount(id) {
        return _.isEqual(_.get(this, '_entity.account._id'), id);
    }

    _getPartialJson() {
        return this.toJson();

    }
}

module.exports = RuntimeEnvironment;
