const _ = require('lodash');
const Types = require('./Types');
const User = require('./User');
const ExecutionContext = require('./ExecutionContext');
const System = require('./System');
const RuntimeEnvironment = require('./RuntimeEnvironment');
const Engine = require('./Engine');
const Agent = require('./Agent');
const ArgoRuntime = require('./ArgoRuntime');
const { setInternalRequestLogic } = require('./internalRequest');

/**
 * Use this static method to create new User entity encoded string
 * @param encoded String
 * @return {User|System}
 */
const constructFromEncodedString = (encoded) => {
    if (!_.isString(encoded)) {
        throw new Error('constructFromEncodedString failed. Given parameter is not string');
    }

    const jsonStr = Buffer.from(encoded, 'base64').toString();
    let parsedJsonEntity;
    try {
        parsedJsonEntity = JSON.parse(jsonStr);
    } catch (err) {
        throw new Error('constructFromEncodedString failed. Given parameter is not in JSON format');
    }

    switch (parsedJsonEntity.type) {
        case Types.USER:
            return new User(parsedJsonEntity);
        case Types.SYSTEM:
            return new System(parsedJsonEntity.serviceName);
        case Types.RUNTIME_ENVIRONMENT:
            return new RuntimeEnvironment(parsedJsonEntity);
        case Types.ENGINE:
            return new Engine(parsedJsonEntity);
        case Types.AGENT:
            return new Agent(parsedJsonEntity);
        case Types.EXECUTION_CONTEXT:
            return new ExecutionContext(parsedJsonEntity);
        case Types.ARGO_RUNTIME:
            return new ArgoRuntime(parsedJsonEntity);
        case undefined:
            parsedJsonEntity.type = Types.USER;
            return new User(parsedJsonEntity);
        default:
            throw new Error(`constructFromEncodedString failed. Given encoded entity type: ${parsedJsonEntity.type} is not supported`);
    }
};


module.exports = {
    User,
    ExecutionContext,
    RuntimeEnvironment,
    System,
    Engine,
    Agent,
    ArgoRuntime,
    constructFromEncodedString,
    Types,
    setInternalRequestLogic
};
