'use strict';


const _ = require('lodash');
const chai = require('chai');
const sinonChai = require('sinon-chai');

const expect = chai.expect;
const { Agent } = require('../index');
const { AGENT } = require('./../Types');

chai.use(sinonChai);

const getValidConfig = () => {
    return {
        account: {
            name: 'fake-account-name',
            _id: 'fake-account-id',
            features: {
                key: 'val'
            }
        },
        name: 'fake-agent-name'
    };
};

describe('Agent unit test', () => {

    it('should return agent type', () => {
        const agent = new Agent(getValidConfig());
        expect(agent.getType()).to.equal(AGENT);
    });
    it('should throw an error in case of no passed account name', () => {
        expect(() => new Agent()).to.throw('Failed to create Auth entity agent without a account name');
    });

    it('should throw an error in case of no passed account id', () => {
        expect(() => new Agent({ account: { name: 'fake-account-name' } })).to.throw('Failed to create Auth entity agent without a account id');
    });

    it('should throw an error in case of no passed runtime environment name', () => {
        expect(() => new Agent({ account: { name: 'fake-account-name', _id: 'fake-account-id' } })).to.throw('Failed to create Auth entity agent without a agent name');
    });

    it('should add feature flags', () => {
        const agent = new Agent(getValidConfig());
        expect(agent.toJson().account.features).to.deep.equal({
            key: 'val'
        });
    });
}

);
