'use strict';

/* eslint-disable no-unused-expressions */
/* eslint-disable no-undef */

const _ = require('lodash');
const chai = require('chai');
const sinonChai = require('sinon-chai');

const expect = chai.expect;
const { System } = require('../index');

chai.use(sinonChai);

describe('System unit ', () => {

    it('should return type system', () => {
        const system = new System('microservice');
        expect(system.getType()).to.equal('system');
    });

    it('should throw an error in case of no passed serviceName', () => {
        try {
            new System();
        } catch (err) {
            expect(err.toString()).to.contain('Failed to create Auth entity System without a service name');
            return;
        }
        throw new Error('should have failed');
    });

    it('should return a json object', () => {
        const system = new System('microservice');
        expect(system.toJson()).to.deep.equal({
            'serviceName': 'microservice',
            'type': 'system'
        });
    });

    it('should return name', () => {
        const system = new System('microservice');
        expect(system.getName()).to.deep.equal('system');
    });

    it('should return a partial json object', () => {
        const system = new System('microservice');
        expect(system.toJson({ partial: true })).to.deep.equal({
            'serviceName': 'microservice',
            'type': 'system'
        });
    });

    it('should return a string for toString', () => {
        const system = new System('microservice');
        expect(system.toString()).to.equal('{"type":"system","serviceName":"microservice"}');
    });

    it('should generate a hashstring', () => {
        const system = new System('microservice');
        expect(system.generateHashString()).to.equal('c6176b4408dd40ec9ae92c7cd5646fb81a393fa11802fd522f81010937d0c59a');
    });

    it('should encode to base 64', () => {
        const system = new System('microservice');
        expect(system.encodeToBase64String()).to.equal('eyJ0eXBlIjoic3lzdGVtIiwic2VydmljZU5hbWUiOiJtaWNyb3NlcnZpY2UifQ==');
    });



});

