'use strict';

/* eslint-disable no-unused-expressions */
/* eslint-disable no-undef */

const _ = require('lodash');
const chai = require('chai');
const sinonChai = require('sinon-chai');

const expect = chai.expect;
const { User, System, constructFromEncodedString } = require('../index');

chai.use(sinonChai);

describe('Index unit ', () => {

    const fakeUserJson = {
        type: 'user',
        _id: 'fake-user-id-1',
        userName: 'fake-userName',
        account: [
            {
                name: 'fake-account-name-1',
                _id: 'fake-accountId-1',
                admins: ['fake-user-id-2', 'fake-user-id-1']
            },
            {
                name: 'fake-account-name-2',
                _id: 'fake-accountId-2',
                admins: ['fake-user-id-2', 'fake-user-id-3']
            }
        ]
    };
    const encodedFakeUser = User.constructFromUserEntity(fakeUserJson).encodeToBase64String();
    const encodedFakeSystem = new System('microservice').encodeToBase64String();


    describe('positive', () => {
        it('should return an instance of User entity', () => {
           const user = constructFromEncodedString(encodedFakeUser);
           expect(user).to.be.instanceOf(User);
           expect(user.getType()).to.equal('user');
        });

        it('should reeturn an instance of System entity', () => {
            const user = constructFromEncodedString(encodedFakeSystem);
            expect(user).to.be.instanceOf(System);
            expect(user.getType()).to.equal('system');
        });

        it('should return a user entitiy in case type field does not exist', () => {
            const user = User.constructFromUserEntity(fakeUserJson);
            delete user._entity.type;
            const encodedWithoutType = user.encodeToBase64String();

            const authEntity = constructFromEncodedString(encodedWithoutType);
            expect(authEntity).to.be.instanceOf(User);
        });

        it('should return userAgent after encoding and constructing', () => {
            const user = constructFromEncodedString(encodedFakeUser);
            user.userAgent = 'engine-v1.0.0';
            expect(user.getUserAgentType()).to.equal('engine');
            expect(user.getUserAgentVersion()).to.equal('1.0.0');

            const encodedUser = user.encodeToBase64String();
            const finalUser = constructFromEncodedString(encodedUser);

            expect(finalUser).to.be.instanceOf(User);
            expect(finalUser.getType()).to.equal('user');
            expect(finalUser.getUserAgentType()).to.equal('engine');
            expect(finalUser.getUserAgentVersion()).to.equal('1.0.0');
        });
    });

    describe('negative', () => {

        it('should fail in case provided input is not a string', () => {
            try {
                constructFromEncodedString({});
            } catch (err) {
                expect(err.toString()).to.contain('Given parameter is not string');
                return;
            }
            throw new Error('should have failed');
        });

        it('should fail in case provided string is not a stringified json', () => {
            try {
                const validStringifiedJson = JSON.stringify({key: 'value'});
                const nonValidStringifiedJson = validStringifiedJson + ';';
                constructFromEncodedString(nonValidStringifiedJson);
            } catch (err) {
                expect(err.toString()).to.contain('Given parameter is not in JSON format');
                return;
            }
            throw new Error('should have failed');
        });

        it('should fail if given authenticated entity type is not supported', () => {
            const nonSupportedEncodedStringOfEntity = Buffer.from(JSON.stringify({type: 'non-supported'})).toString('base64')
            try {
                constructFromEncodedString(nonSupportedEncodedStringOfEntity);
            } catch (err) {
                expect(err.toString()).to.contain('Given encoded entity type: non-supported is not supported');
                return;
            }
            throw new Error('should have failed');
        });

    });

});

